
</br>
</br>
<p align="center"> 
    <img height="150" src="https://github.com/rivo2302/airtel_money_api/blob/main/assets/airtel.png?raw=true">
</p>
<div align="center"> 
    <p>
        A <b>light</b> Python module for your <a href="https://developers.airtel.africa/home"> API Airtel </a>.
        <h4>
            <a href="https://pypi.org/project/airtel/">Documentation</a>
            <span> | </span>
            <a href="https://github.com/rivo2302/airtel_money_api/issues">Report bugs</a>
            <span> | </span>
            <a href="https://github.com/rivo2302/airtel_money_api/fork">Contribute</a>
        </h4>
    </p>
    <p>
        <a href='https://pypi.org/project/airtel/'><img src='https://img.shields.io/pypi/v/airtel?style=for-the-badge'/></a>
        <a href='https://github.com/rivo2302/airtel_money_api/fork'> 
            <img src="https://img.shields.io/badge/-python-396E9B?style=for-the-badge&logo=python&logoColor=FFFFFF"/>
        </a>
        <a href='https://pypi.org/project/airtel/'> 
             <img src='https://img.shields.io/pypi/dm/airtle?label=DOWNLOADS&style=for-the-badge'/>
        </a>
        <a href='#'> 
            <img src='https://img.shields.io/badge/Maintained-Yes-darkgreen?style=for-the-badge'/>
        </a>  
    </p>
</div>

